@@ -1,6 +1,6 @@
-import os
-import pandas as pd
+# import os
+# import pandas as pd
+
 
 def read_bnet_file(file_or_filepath):
-
-    pass
\ No newline at end of file
+    pass
